#!/usr/pkg/bin/perl

use Getopt::Long;

my $gpio_port;
my $gpio_pin;
my $verbose;
my $debug;
my $sample_time = 8;
my $loops = 5;
my $sleep_time = 5;

GetOptions("gpio-port|gpio|gpio_port=s" => \$gpio_port,
	   "pin=i" => \$gpio_pin,
	   "sample-time|sample_time=i" => \$sample_time,
	   "loops=i" => \$loops,
	   "sleep-time|sleep_time=i" => \$sleep_time,
	   "verbose+" => \$verbose,
	   "debug+" => \$debug
    ) or die("Error in command line arguments\n");

if (defined $gpio_port && defined $gpio_pin) {
    while ($loops > 0) {
	my @acc = ();
	my $xtime = time;
	while (1) {
	    my $ctime;
	    my $r;
	    $r = `/usr/sbin/gpioctl -s $gpio_port $gpio_pin`;
	    if (defined $debug && $debug > 2) {
		print "R: $r\n";
	    }
	    push(@acc,$r);
	    $ctime = time;
	    if (defined $debug && $debug > 2) {
		print "CTIME: $ctime ; XTIME: $xtime ; SAMPLE_TIME: $sample_time\n";
	    }
	    if (($ctime - $xtime) >= $sample_time) {
		last;
	    }
	}
	my $last_acc;
	my $acount;

	if (defined $debug) {
	    print "NUM ACC: $#acc\n";
	}

	my @results;
	
	foreach (@acc) {
	    chop;
	    if (! defined $last_acc) {
		$last_acc = $_;
		$account = 1;
	    } else {
		if ($last_acc ne $_) {
		    if (defined $verbose || defined $debug) {
			print "LAST_ACC: $last_acc ; ACOUNT: $acount\n";
		    }
		    push(@results,$last_acc);
		    $acount = 1;
		    $last_acc = $_;
		} else {
		    $acount++;
		}
	    }
	}

	if (defined $debug) {
	    print "RESULTS: $#results\n";
	}
	if ($#results > 2) {
	    print "Nav sync.\n";
	    last;
	}
	$loops--;
	if ($loops > 0) {
	    sleep($sleep_time);
	}
    }
    if ($loops == 0) {
	print "Unknown nav sync.\n";
    }
} else {
    print "Missing gpio and pin\n";
    exit 1;
}
